@@ -1,18 +1,20 @@
 # Copyrights 2011-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
 use warnings;
 use strict;
 
 package IOMux::Bundle;
 use vars '$VERSION';
-$VERSION = '0.13';
+$VERSION = '1.00';
 
 use base 'IOMux::Handler::Read', 'IOMux::Handler::Write';
 
 use Log::Report 'iomux';
 
+use Scalar::Util   qw(blessed);
+
 ##### WORK IN PROGRESS!
 
 
@@ -21,29 +23,33 @@ sub init($)
 
     # stdin to be a writer is a bit counter-intuitive, therefore some
     # extra tests.
+
+    my @filenos;
     my $name = $args->{name};
 
     my $in   = $self->{IMB_stdin}  = $args->{stdin}
         or error __x"no stdin handler for {name}", name => $name;
-    UNIVERSAL::isa($in, 'IOMux::Handler::Write')
+    blessed $in && $in->isa('IOMux::Handler::Write')
         or error __x"stdin {name} is not at writer", name => $name;
+    push @filenos, $in->fileno;
 
     my $out = $self->{IMB_stdout} = $args->{stdout}
         or error __x"no stdout handler for {name}", name => $name;
-    UNIVERSAL::isa($out, 'IOMux::Handler::Read')
+    blessed $out && $out->isa('IOMux::Handler::Read')
         or error __x"stdout {name} is not at reader", name => $name;
+    push @filenos, $out->fileno;
 
-    my $err = $self->{IMB_stderr} = $args->{stderr};
-    !$err || UNIVERSAL::isa($out, 'IOMux::Handler::Read')
-        or error __x"stderr {name} is not at reader", name => $name;
+    if(my $err = $self->{IMB_stderr} = $args->{stderr})
+    {   blessed $err && $err->isa('IOMux::Handler::Read')
+            or error __x"stderr {name} is not at reader", name => $name;
+        push @filenos, $err->fileno;
+    }
 
-    my @filenos = ($in->fileno, $out->fileno);
-    push @filenos, $err->fileno if $err;
-
-    $self->{IMB_filenos} = \@filenos;
-    $args->{name} .= ', ('.join(',',@filenos).')';
+    $args->{name}       .= ', ('.join(',',@filenos).')';
 
     $self->SUPER::init($args);
+
+    $self->{IMB_filenos} = \@filenos;
     $self;
 }
 
@@ -53,34 +59,32 @@ sub stdin()  {shift->{IMB_stdin}}
 sub stdout() {shift->{IMB_stdout}}
 sub stderr() {shift->{IMB_stderr}}
 
+
 sub connections()
-{   my $self = shift;
-    ( $self->{IMB_stdin}
-    , $self->{IMB_stdout},
-    , ($self->{IMB_stderr} ? $self->{IMB_stderr} : ())
-    );
+{   my $s = shift;
+    grep defined, $s->{IMB_stdin}, $s->{IMB_stdout}, $s->{IMB_stderr};
 }
 
 #---------------
 
 # say, print and printf use write()
-sub write(@)     { shift->{IMB_stdin}->write(@_) }
-sub mux_outbuffer_empty() { shift->{IMB_stdin}->mux_outbuffer_empty(@_) }
-sub mux_output_waiting()  { shift->{IMB_stdin}->mux_output_waiting(@_) }
-sub mux_write_flagged()   { shift->{IMB_stdin}->mux_write_flagged(@_) }
+sub write(@)            { shift->{IMB_stdin}->write(@_) }
+sub muxOutbufferEmpty() { shift->{IMB_stdin}->muxOutbufferEmpty(@_) }
+sub muxOutputWaiting()  { shift->{IMB_stdin}->muxOutputWaiting(@_)  }
+sub muxWriteFlagged()   { shift->{IMB_stdin}->muxWriteFlagged(@_)   }
 
-sub readline(@)  { shift->{IMB_stdout}->readline(@_)  }
-sub slurp(@)     { shift->{IMB_stdout}->slurp(@_)     }
-sub mux_input($) { shift->{IMB_stdout}->mux_input(@_) }
-sub mux_eof($)   { shift->{IMB_stdout}->mux_eof(@_)   }
+sub readline(@)         { shift->{IMB_stdout}->readline(@_) }
+sub slurp(@)            { shift->{IMB_stdout}->slurp(@_)    }
+sub muxInput($)         { shift->{IMB_stdout}->muxInput(@_) }
+sub muxEOF($)           { shift->{IMB_stdout}->muxEOF(@_)   }
 
-sub mux_read_flagged($)
+sub muxReadFlagged($)
 {   my ($self, $fileno) = @_;
     if(my $e = $self->{IMB_stderr})
-    {   return $e->mux_read_flagged(@_)
+    {   return $e->muxReadFlagged(@_)
             if $fileno==$e->fileno;
     }
-    $self->{IMB_stdin}->mux_read_flagged(@_);
+    $self->{IMB_stdin}->muxReadFlagged(@_);
 }
 
 sub timeout() { shift->{IMB_stdin}->timeout(@_) }
@@ -101,16 +105,16 @@ sub close(;$)
     else { $close_out->() }
 }
 
-sub mux_remove()
+sub muxRemove()
 {   my $self = shift;
-    $_->mux_remove for $self->connections;
+    $_->muxRemove for $self->connections;
     trace "mux remove bundle ".$self->name;
 }
 
-sub mux_init($)
+sub muxInit($)
 {   my ($self, $mux) = @_;
 
-    $_->mux_init($mux, $self)  # I want control
+    $_->muxInit($mux, $self)  # I want control
         for $self->connections;
 
     trace "mux add bundle ".$self->name;
@@ -118,7 +122,7 @@ sub mux_init($)
 
 #---------------
  
-sub mux_error($)
+sub muxError($)
 {   my ($self, $errbuf) = @_;
     print STDERR $$errbuf;
     $$errbuf = '';
@@ -128,7 +132,7 @@ sub mux_error($)
 
 sub show()
 {   my $self = shift;
-    join "\n", map({$_->show} $self->connections),'';
+    join "\n", (map $_->show, $self->connections), '';
 }
 
 sub fdset() {panic}
