@@ -1,13 +1,13 @@
 # Copyrights 2011-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
 use warnings;
 use strict;
 
 package IOMux::Handler;
 use vars '$VERSION';
-$VERSION = '0.13';
+$VERSION = '1.00';
 
 
 use Log::Report  'iomux';
@@ -24,12 +24,12 @@ sub new(@)  {my $class = shift; (bless {}, $class)->init( {@_} ) }
 
 sub init($)
 {   my ($self, $args) = @_;
-    return $self if $self->{IMH_name}; # already initialized
+    return $self if $self->{IH_name}; # already initialized
 
-    my $name = $self->{IMH_name} = $args->{name} || "$self";
-    if(my $fh = $self->{IMH_fh} = $args->{fh})
-    {   $self->{IMH_fileno}   = $fh->fileno;
-        $self->{IMH_uses_ssl} = UNIVERSAL::isa($fh, 'IO::Socket::SSL');
+    my $name = $self->{IH_name} = $args->{name} || "$self";
+    if(my $fh = $self->{IH_fh} = $args->{fh})
+    {   $self->{IH_fileno}   = $fh->fileno;
+        $self->{IH_uses_ssl} = UNIVERSAL::isa($fh, 'IO::Socket::SSL');
     }
     $self;
 }
@@ -39,35 +39,36 @@ sub open() {panic}
 
 #-------------------------
 
-sub name()   {shift->{IMH_name}}
-sub mux()    {shift->{IMH_mux}}
+sub name()   {shift->{IH_name}}
+sub mux()    {shift->{IH_mux}}
 
 
-sub fileno() {shift->{IMH_fileno}}
-sub fh()     {shift->{IMH_fh}}
-sub usesSSL(){shift->{IMH_uses_ssl}}
+sub fileno() {shift->{IH_fileno}}
+sub fh()     {shift->{IH_fh}}
+sub usesSSL(){shift->{IH_uses_ssl}}
 
 #-----------------------
 
 sub timeout(;$)
 {   my $self  = shift;
-    @_ or return $self->{IMH_timeout};
+    @_ or return $self->{IH_timeout};
 
-    my $old   = $self->{IMH_timeout};
+    my $old   = $self->{IH_timeout};
     my $after = shift;
     my $when  = !$after      ? undef
       : $after > $start_time ? $after
       :                        ($after + time);
-    $self->{IMH_mux}->changeTimeout($self->{IMH_fileno}, $old, $when);
-    $self->{IMH_timeout} = $when;
+
+    $self->{IH_mux}->changeTimeout($self->{IH_fileno}, $old, $when);
+    $self->{IH_timeout} = $when;
 }
 
 
 sub close(;$)
 {   my ($self, $cb) = @_;
-    if(my $fh = delete $self->{IMH_fh})
-    {   if(my $mux = $self->{IMH_mux})
-        {   $mux->remove($self->{IMH_fileno});
+    if(my $fh = delete $self->{IH_fh})
+    {   if(my $mux = $self->{IH_mux})
+        {   $mux->remove($self->{IH_fileno});
         }
         $fh->close;
     }
@@ -77,31 +78,33 @@ sub close(;$)
 
 #-------------------------
 
-sub mux_init($;$)
+sub muxInit($;$)
 {   my ($self, $mux, $handler) = @_;
 
-    $self->{IMH_mux} = $mux;
-    weaken($self->{IMH_mux});
+    $self->{IH_mux} = $mux;
+    weaken($self->{IH_mux});
 
-    my $fileno = $self->{IMH_fileno};
+    my $fileno = $self->{IH_fileno};
     $mux->handler($fileno, $handler || $self);
 
-    if(my $timeout = $self->{IMH_timeout})
+    if(my $timeout = $self->{IH_timeout})
     {   $mux->changeTimeout($fileno, undef, $timeout);
     }
 
-    trace "mux add #$fileno, $self->{IMH_name}";
+    trace "mux add #$fileno, $self->{IH_name}";
 }
 
 
-sub mux_remove()
+sub muxRemove()
 {   my $self = shift;
-    delete $self->{IMH_mux};
-    trace "mux remove #$self->{IMH_fileno}, $self->{IMH_name}";
+    delete $self->{IH_mux};
+#use Carp 'cluck';
+#cluck "REMOVE";
+    trace "mux remove #$self->{IH_fileno}, $self->{IH_name}";
 }
 
 
-sub mux_timeout()
+sub muxTimeout()
 {   my $self = shift;
     error __x"timeout set on {name} but not handled", name => $self->name;
 }
@@ -109,13 +112,13 @@ sub mux_timeout()
 #----------------------
 
 
-sub mux_read_flagged($)  { panic "no input expected on ". shift->name }
+#sub muxReadFlagged($)  { panic "no input expected on ". shift->name }
 
 
-sub mux_except_flagged($)  { panic "exception arrived on ". shift->name }
+#sub muxExceptFlagged($)  { panic "exception arrived on ". shift->name }
 
 
-sub mux_write_flagged($) { shift }  # simply ignore write offers
+#sub muxWriteFlagged($) { shift }  # simply ignore write offers
 
 
 #-------------------------
@@ -150,19 +153,19 @@ sub show()
 
 sub fdset($$$$)
 {   my $self = shift;
-    $self->{IMH_mux}->fdset($self->{IMH_fileno}, @_);
+    $self->{IH_mux}->fdset($self->{IH_fileno}, @_);
 }
 
 
 sub extractSocket($)
 {   my ($thing, $args) = @_;
-    my $class  = ref $thing || $thing;
+    my $class    = ref $thing || $thing;
 
-    my $socket = delete $args->{socket};
+    my $socket   = delete $args->{socket};
     return $socket if $socket;
 
-    my @sockopts;
-    push @sockopts, $_ => delete $args->{$_}
+    my @sockopts = (Blocking => 0);
+    push @sockopts, $_ => $args->{$_}
         for grep /^[A-Z]/, keys %$args;
 
     @sockopts
@@ -173,7 +176,7 @@ sub extractSocket($)
 
     # the extension will load these classes
     my $make = $ssl ? 'IO::Socket::SSL' : 'IO::Socket::INET';
-    $socket  = $make->new(Blocking => 0, @sockopts)
+    $socket  = $make->new(@sockopts)
         or fault __x"cannot create {pkg} socket", pkg => $class;
 
     $socket;
